Utility functions for DNS resolution and IP operations. Utility functions for Bitfold networking.
Address utilities for DNS and IP operations:
- DNS resolution (hostname to IP)
- Reverse DNS lookup (IP to hostname)
- IP string parsing and formatting
Functions
- format_
ip - Formats a socket address to an IP string (without reverse DNS lookup).
- format_
ip_ addr - Formats an IP address to a string.
- parse_
ip - Parses an IP address string (without DNS resolution) to a socket address.
- resolve_
host - Resolves a hostname to a socket address using DNS.
- reverse_
lookup - Performs reverse DNS lookup to get the hostname for an IP address.